@@ -5,7 +5,7 @@ import operator
 from variables import *
 
 
-VERSION = '0.1.1'
+VERSION = '0.1.2'
 __all__ = []
 
 def get_dict(object):
@@ -32,10 +32,11 @@ def run_compare(actual, expected = True, func = operator.eq):
         get_current_test_method().set_failed()
     return actual
 
-def must_equal(self, other):
-    return run_compare(self, other)
+def must_equal(self, other, key=operator.eq):
+    return run_compare(self, other, key)
 
 def must_equal_with_func(self, other, func):
+    ''' deprecated, now just use must_equal's key parameter '''
     return run_compare(self, other, func)
 
 def must_true(self):
@@ -60,12 +61,20 @@ def pp(self):
     pprint(self)
     return self
 
+def length(self):
+    return len(self)
+
+def size(self):
+    return len(self)
+
 def inject_musts_methods():
     [set_method_to_object(func) for name, func 
         in globals().iteritems() 
         if name.startswith('must_')]
     set_method_to_object(p)
     set_method_to_object(pp)
+    set_method_to_object(length)
+    set_method_to_object(size)
 
 
 inject_musts_methods()
